// Tide Protocol - Infrastructure for the Personal Data economy
// Copyright (C) 2019 Tide Foundation Ltd
// 
// This program is free software and is subject to the terms of 
// the Tide Community Open Source License as published by the 
// Tide Foundation Limited. You may modify it and redistribute 
// it in accordance with and subject to the terms of that License.
// This program is distributed WITHOUT WARRANTY of any kind, 
// including without any implied warranty of MERCHANTABILITY or 
// FITNESS FOR A PARTICULAR PURPOSE.
// See the Tide Community Open Source License for more details.
// You should have received a copy of the Tide Community Open 
// Source License along with this program.
// If not, see https://tide.org/licenses_tcosl-1-0-en

import secretShare from './secretShare';
import EcScalar from './ecScalar';

export default class EcSecretShare {
    /**
     * @param {EcScalar} secret
     * @param {EcScalar[]} ids
     * @param {number} threshold
     */
    static shareFromIds(secret, ids, threshold) {
        var [_, shrs] = secretShare.shareFromIds(secret.value, ids.map(id => id.value), threshold, secret.p);
        return [ids, shrs.map(shr => new EcScalar(shr))]
    }

    /**
     * @param {EcScalar} id 
     * @param {EcScalar[]} ids
     * @returns {EcScalar}
     */
    static getLi(id, ids) {
        return secretShare.getLi(id.value, ids.map(idj => idj.value), id.p);
    }
}
